# Note: this file has been initially generated by Module::Build::Convert 0.49

use 5.008008;
use strict;
use warnings;

use Module::Build;

my $build = Module::Build->new
  (
   module_name => 'RPSL::Parser',
   dist_version_from => 'lib/RPSL/Parser.pm',
   requires => { 'Class::Accessor' => 0.31 },
   license => 'perl',
   create_readme => 1,
   create_makefile_pl => 'traditional',
  );

$build->create_build_script;
